@@ -23,23 +23,17 @@ import scala.util.Try
 import org.apache.spark.SparkConf
 import org.scalatest.Outcome
 
-import org.apache.kyuubi.plugin.spark.authz.util.AuthZUtils._
+import org.apache.kyuubi.plugin.spark.authz.V2JdbcTableCatalogPrivilegesBuilderSuite._
 
 class DataMaskingForJDBCV2Suite extends DataMaskingTestBase {
   override protected val extraSparkConf: SparkConf = {
-    val conf = new SparkConf()
-    if (isSparkV31OrGreater) {
-      conf
-        .set("spark.sql.defaultCatalog", "testcat")
-        .set(
-          "spark.sql.catalog.testcat",
-          "org.apache.spark.sql.execution.datasources.v2.jdbc.JDBCTableCatalog")
-        .set(s"spark.sql.catalog.testcat.url", "jdbc:derby:memory:testcat;create=true")
-        .set(
-          s"spark.sql.catalog.testcat.driver",
-          "org.apache.derby.jdbc.AutoloadedDriver")
-    }
-    conf
+    new SparkConf()
+      .set("spark.sql.defaultCatalog", "testcat")
+      .set("spark.sql.catalog.testcat", v2JdbcTableCatalogClassName)
+      .set(s"spark.sql.catalog.testcat.url", "jdbc:derby:memory:testcat;create=true")
+      .set(
+        s"spark.sql.catalog.testcat.driver",
+        "org.apache.derby.jdbc.AutoloadedDriver")
   }
 
   override protected val catalogImpl: String = "in-memory"
@@ -47,21 +41,18 @@ class DataMaskingForJDBCV2Suite extends DataMaskingTestBase {
   override protected def format: String = ""
 
   override def beforeAll(): Unit = {
-    if (isSparkV31OrGreater) super.beforeAll()
+    super.beforeAll()
   }
 
   override def afterAll(): Unit = {
-    if (isSparkV31OrGreater) {
-      super.afterAll()
-      // cleanup db
-      Try {
-        DriverManager.getConnection(s"jdbc:derby:memory:testcat;shutdown=true")
-      }
+    super.afterAll()
+    // cleanup db
+    Try {
+      DriverManager.getConnection(s"jdbc:derby:memory:testcat;shutdown=true")
     }
   }
 
   override def withFixture(test: NoArgTest): Outcome = {
-    assume(isSparkV31OrGreater)
     test()
   }
 }
