@@ -18,13 +18,14 @@
 package org.apache.kyuubi.engine.spark.events
 
 import com.fasterxml.jackson.annotation.JsonIgnore
+import com.fasterxml.jackson.databind.annotation.{JsonDeserialize, JsonSerialize}
 import org.apache.spark.scheduler.SparkListenerEvent
 import org.apache.spark.util.kvstore.KVIndex
 
 import org.apache.kyuubi.Utils
 import org.apache.kyuubi.engine.spark.KyuubiSparkUtil.KVIndexParam
 import org.apache.kyuubi.engine.spark.operation.SparkOperation
-import org.apache.kyuubi.events.KyuubiEvent
+import org.apache.kyuubi.events.{ExceptionDeserializer, ExceptionSerializer, KyuubiEvent}
 
 /**
  * A [[SparkOperationEvent]] used to tracker the lifecycle of an operation at Spark SQL Engine side.
@@ -60,6 +61,8 @@ case class SparkOperationEvent(
     createTime: Long,
     startTime: Long,
     completeTime: Long,
+    @JsonSerialize(contentUsing = classOf[ExceptionSerializer])
+    @JsonDeserialize(contentUsing = classOf[ExceptionDeserializer])
     exception: Option[Throwable],
     sessionId: String,
     sessionUser: String,
