@@ -21,12 +21,6 @@ trait JdbcDatabaseDialect {
   def limitClause(limit: Int, offset: Int): String
 }
 
-class DerbyDatabaseDialect extends JdbcDatabaseDialect {
-  override def limitClause(limit: Int, offset: Int): String = {
-    s"OFFSET $offset ROWS FETCH NEXT $limit ROWS ONLY"
-  }
-}
-
 class GenericDatabaseDialect extends JdbcDatabaseDialect {
   override def limitClause(limit: Int, offset: Int): String = {
     s"LIMIT $limit OFFSET $offset"
@@ -35,3 +29,4 @@ class GenericDatabaseDialect extends JdbcDatabaseDialect {
 
 class SQLiteDatabaseDialect extends GenericDatabaseDialect {}
 class MySQLDatabaseDialect extends GenericDatabaseDialect {}
+class PostgreSQLDatabaseDialect extends GenericDatabaseDialect {}
